var prefs = (function (adw1, gtk4) {
    'use strict';

    const ExtensionUtils = imports.misc.extensionUtils;
    const SettingsPath = "org.gnome.shell.extensions.quicksettings-audio-devices-hider";
    const ExcludedOutputNamesSetting = "excluded-output-names";
    const AvailableOutputNames = "available-output-names";
    class SettingsUtils {
        constructor() {
            this.settings = null;
        }
        getSettings() {
            if (!this.settings) {
                this.settings = ExtensionUtils.getSettings(SettingsPath);
            }
            return this.settings;
        }
        getExcludedOutputDeviceNames() {
            const settings = this.getSettings();
            const ids = settings.get_strv(ExcludedOutputNamesSetting);
            return ids;
        }
        setExcludedOutputDeviceNames(displayNames) {
            const settings = this.getSettings();
            settings.set_strv(ExcludedOutputNamesSetting, displayNames);
        }
        addToExcludedOutputDeviceNames(displayName) {
            const currentOutputs = this.getExcludedOutputDeviceNames();
            if (currentOutputs.includes(displayName)) {
                return;
            }
            const newOutputs = [...currentOutputs, displayName];
            const settings = this.getSettings();
            settings.set_strv(ExcludedOutputNamesSetting, newOutputs);
        }
        removeFromExcludedOutputDeviceNames(displayName) {
            const outputs = this.getExcludedOutputDeviceNames();
            const index = outputs.indexOf(displayName);
            if (index === -1) {
                return;
            }
            outputs.splice(index, 1);
            const settings = this.getSettings();
            settings.set_strv(ExcludedOutputNamesSetting, outputs);
        }
        getAvailableOutputs() {
            const settings = this.getSettings();
            const ids = settings.get_strv(AvailableOutputNames);
            return ids;
        }
        setAvailableOutputs(displayNames) {
            const settings = this.getSettings();
            settings.set_strv(AvailableOutputNames, displayNames.map((id) => id.toString()));
        }
        addToAvailableOutputs(displayName) {
            const currentOutputs = this.getAvailableOutputs();
            if (currentOutputs.includes(displayName)) {
                return;
            }
            const newAllOutputs = [...currentOutputs, displayName];
            const settings = this.getSettings();
            settings.set_strv(AvailableOutputNames, newAllOutputs.map((id) => id.toString()));
        }
        removeFromAvailableOutputs(displayName) {
            const outputs = this.getAvailableOutputs();
            const index = outputs.indexOf(displayName);
            if (index === -1) {
                return;
            }
            outputs.splice(index, 1);
            const settings = this.getSettings();
            settings.set_strv(AvailableOutputNames, outputs.map((id) => id.toString()));
        }
        connectToChanges(settingName, func) {
            return this.getSettings().connect(`changed::${settingName}`, func);
        }
        disconnect(subscriptionId) {
            this.getSettings().disconnect(subscriptionId);
        }
        dispose() {
            this.settings = null;
        }
    }

    function init() { }
    function fillPreferencesWindow(window) {
        const page = new adw1.PreferencesPage();
        window.add(page);
        let settings = new SettingsUtils();
        window.connect("close-request", () => {
            settings?.dispose();
            settings = null;
        });
        const allDevices = settings.getAvailableOutputs();
        const hiddenDevices = settings.getExcludedOutputDeviceNames();
        var visibleDevices = allDevices.filter((device) => !hiddenDevices.includes(device));
        const group = new adw1.PreferencesGroup({
            title: "Output Audio Devices",
            description: "Choose which devices should be visible in the Quick Setting panel",
        });
        page.add(group);
        visibleDevices.forEach((device) => {
            group.add(createDeviceRow(device, true, settings));
        });
        hiddenDevices.forEach((device) => {
            group.add(createDeviceRow(device, false, settings));
        });
    }
    function createDeviceRow(displayName, active, settings) {
        const row = new adw1.ActionRow({ title: displayName });
        const toggle = new gtk4.Switch({
            active,
            valign: gtk4.Align.CENTER,
        });
        toggle.connect("state-set", (_, state) => {
            if (state) {
                settings.removeFromExcludedOutputDeviceNames(displayName);
            }
            else {
                settings.addToExcludedOutputDeviceNames(displayName);
            }
            return false;
        });
        row.add_suffix(toggle);
        row.activatable_widget = toggle;
        return row;
    }
    var prefs = { init, fillPreferencesWindow };

    return prefs;

})(imports.gi.Adw, imports.gi.Gtk);
var init = prefs.init;
var fillPreferencesWindow = prefs.fillPreferencesWindow;
